@@ -67,6 +67,10 @@ class Hypervisor(object):
 			elif self.__is_hypervisor_qemu():
 				return "Qemu"
 
+			# Check for Microsoft.
+			elif self.__is_hypervisor_microsoft():
+				return "Microsoft"
+
 		return "unknown"
 
 	@property
@@ -96,7 +100,8 @@ class Hypervisor(object):
 			"hypervisor" in self.system.cpu.flags or \
 			self.__is_hypervisor_virtualbox() or \
 			self.__is_hypervisor_vmware() or \
-			self.__is_hypervisor_qemu()
+			self.__is_hypervisor_qemu() or \
+			self.__is_hypervisor_microsoft()
 
 	def __is_hypervisor_virtualbox(self):
 		"""
@@ -123,6 +128,12 @@ class Hypervisor(object):
 		"""
 		return self.system.bios_vendor == "Bochs"
 
+	def __is_hypervisor_microsoft(self):
+		"""
+			Check for Microsoft hypervisor.
+		"""
+		return "Microsoft" in self.system.vendor
+
 
 if __name__ == "__main__":
 	h = Hypervisor()
